pydevDAG._attributes._types module — pydevDAG 1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »
- pydevDAG._attributes package »

# pydevDAG._attributes._types module

## pydevDAG._types

Types of graph nodes and edges.

class `pydevDAG._attributes._types.` `EdgeType`

  Bases: `pydevDAG._attributes._metaclasses.AttributeValue`

  Superclass of edge types.

class `pydevDAG._attributes._types.` `EdgeTypes`

  Bases: `pydevDAG._attributes._metaclasses.AttributeValues`

  Enumeration of edge types.

  `CONGRUENCE` = Congruence
  `PARTITION` = Partition
  `SLAVE` = Slave
  `SPINDLE` = Spindle
  classmethod `values`()

class `pydevDAG._attributes._types.` `NodeType`

  Bases: `pydevDAG._attributes._metaclasses.AttributeValue`

  Abstract class that represents a node type.

class `pydevDAG._attributes._types.` `NodeTypes`

  Bases: `pydevDAG._attributes._metaclasses.AttributeValues`

  Enumeration of node types.

  `DEVICE_PATH` = DevicePath
  `WWN` = WWN
  classmethod `values`()

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »
- pydevDAG._attributes package »